| Title: | Web Interface to 'IsoplotR' |
|---|---|
| Description: | Provides a graphical user interface to the 'IsoplotR' package for radiometric geochronology. The GUI runs in an internet browser and can either be used offline, or hosted on a server to provide online access to the 'IsoplotR' toolbox. |
| Authors: | Pieter Vermeesch [aut, cre], Tim Band [ctb] |
| Maintainer: | Pieter Vermeesch <[email protected]> |
| License: | GPL-3 |
| Version: | 6.8.5 |
| Built: | 2026-05-25 10:44:13 UTC |
| Source: | https://github.com/pvermees/isoplotrgui |
IsoplotR GUI without exitingOpens a web-browser with a Graphical User Interface (GUI) for the
IsoplotR package. This function is intended to be used from
Rscript so that Rscript does not terminate and the server stays up.
daemon(port = NULL, host = "127.0.0.1", timeout = 30)daemon(port = NULL, host = "127.0.0.1", timeout = 30)
port |
Internet port of the virtual server. If not defined, a random free port will be chosen and the browser will be opened to show the GUI. |
host |
IP address of the virtual server |
timeout |
How long (in elapsed time) an operation may take before returning with a timeout error. Default: 30 seconds. |
This function does not return.
# this function runs indefinitely unless interrupted by the user. ## Not run: daemon(3839)# this function runs indefinitely unless interrupted by the user. ## Not run: daemon(3839)
IsoplotR GUIOpens a web-browser with a Graphical User Interface (GUI) for the
IsoplotR package. An online version of the same interface is
provided at https://isoplotr.es.ucl.ac.uk/
IsoplotR( host = if (daemonize) "0.0.0.0" else "127.0.0.1", port = NULL, timeout = Inf, daemonize = !is.null(port) )IsoplotR( host = if (daemonize) "0.0.0.0" else "127.0.0.1", port = NULL, timeout = Inf, daemonize = !is.null(port) )
host |
IP address of the virtual server, default is 0.0.0.0 |
port |
Internet port of the virtual server. If not defined, a random free port will be chosen and the browser will be opened to show the GUI. |
timeout |
How long (in wall-clock time) an operation may take before returning with a timeout error. Default: no limit. |
daemonize |
logical. If |
server object
IsoplotR()IsoplotR()
IsoplotR GUIStop an IsoplotR GUI
stopIsoplotR(server = NULL)stopIsoplotR(server = NULL)
server |
The server (returned by
|
s <- IsoplotR() stopIsoplotR(s)s <- IsoplotR() stopIsoplotR(s)